@@ -24,19 +24,23 @@ class CLIInterface(object):
         # Add positional arguments first
         self.parser.add_argument("database", help="PostGIS database name.")
         self.parser.add_argument("SELECT",
-                                 help="SELECT Statement. NOTE: Geometry must be GeoJSON stored in WGS84.")
+                                 help="SELECT Statement. NOTE: Geometry must be WGS84; wrapped in ST_AsGeoJSON() or AsTopoJSON().")
         # Add optional arguments.
         self.parser.add_argument("-f", "--file",
-                                 help="Filename. NOTE: Must end in 'geosjon' or 'topojson' extension.",
+                                 help="Filename. NOTE: Must end in 'geojson' or 'topojson' extension.",
                                  default="upload.geojson")
         self.parser.add_argument("-d", "--description",
                                  help="Description of upload",
                                  default="File uploaded using pgsql2gist.")
-        self.parser.add_argument("-h", "--host", help="PostGIS database hostname.", default="localhost")
+        self.parser.add_argument("-h", "--host", help="PostGIS database hostname.")
         self.parser.add_argument("-p", "--port", help="PostGIS database port.", type=int, default=5432)
         self.parser.add_argument("-P", "--password", help="PostGIS user password.")
         self.parser.add_argument("-u", "--user", help="PostGIS database user.", default="postgres")
-        self.parser.add_argument("-g", "--geom-col", help="Geometry Column.", default="geometry")
+        self.parser.add_argument("-g", "--geom-col",
+                                 help="Geometry column name as defined in SELECT statement.",
+                                 default="geometry")
+        self.parser.add_argument("-t", "--topology-layer", help="For TopoJSON Queries; Name of Topology Layer")
+        self.parser.add_argument("-v", "--verbose", help="Verbose output.", action="store_true")
         # Add custom help flag
         self.parser.add_argument("-?", "--help", action="help")
 
@@ -61,10 +65,7 @@ class CLIInterface(object):
         """
         validation_functions = [self._validate_file_ext, self._validate_topojson_geojson_call]
         for func in validation_functions:
-            try:
-                func(args_dict)
-            except Exception, e:
-                raise e
+            func(args_dict)
         return True
 
     def _validate_file_ext(self, args_dict):
@@ -90,7 +91,7 @@ class CLIInterface(object):
         Validate that a user has invoked a call to ST_AsGeoJSON() or ST_AsTopoJSON()
         in their SELECT statement.
         """
-        valid_calls = ['st_asgeojson', 'st_astopojson']
+        valid_calls = ['st_asgeojson', 'astopojson']
         call_is_valid = False
         for call in valid_calls:
             if call.lower() in args_dict['SELECT'].lower():
@@ -98,4 +99,4 @@ class CLIInterface(object):
         if call_is_valid:
             return True
         else:
-            raise ValueError('SELECT statement does not contain call to ST_AsGeoJSON() or ST_AsTopoJSON()')
+            raise ValueError('SELECT statement does not contain call to ST_AsGeoJSON() or AsTopoJSON()')
